@@ -7,8 +7,8 @@
 * Copyright (C) 2001-2007 David LaRose, dlr@cs.cmu.edu
 * See accompanying file, LICENSE.TXT, for details.
 *
-* $Revision: 1038 $
-* $Date: 2008-09-29 14:15:18 -0400 (Mon, 29 Sep 2008) $
+* $Revision: 1182 $
+* $Date: 2009-09-09 11:25:46 -0400 (Wed, 09 Sep 2009) $
 ***************************************************************************
 **/
 
@@ -488,12 +488,28 @@ namespace dlr {
       void
       reinit(size_t arrayRows, size_t arrayColumns);
 
+      
+      /** 
+       * Behaves just like member function reinit() unless *this
+       * already has the requested shape, in which case this member
+       * function does nothing, or *this has the requested size (but a
+       * different shape), in which case this member function behaves
+       * just like member function resize().
+       * 
+       * @param arrayRows Requested row dimension.
+       *
+       * @param arrayColumns Requested column dimension.
+       */
+      inline void
+      reinitIfNecessary(size_t arrayRows, size_t arrayColumns);
+
+
       /**
-       * Changes the shape of the array.  It is an error if arrayRows *
-       * arrayColumns is not equal to this->size().  Either arrayRows or arrayColumns
-       * may be specified as -1, but not both.  If one of the arguments
-       * is -1, its value will be calculated based on the total size of
-       * the array and the value of the other argument.
+       * Changes the shape of the array.  It is an error if
+       * (arrayRows * arrayColumns) is not equal to this->size().  Either
+       * arrayRows or arrayColumns may be specified as -1, but not both.
+       * If one of the arguments is -1, its value will be calculated based
+       * on the total size of the array and the value of the other argument.
        * 
        * @param arrayRows Requested row dimension.
        *
@@ -1652,6 +1668,20 @@ namespace dlr {
     }
 
 
+    template <class Type>
+    void Array2D<Type>::
+    reinitIfNecessary(size_t arrayRows, size_t arrayColumns)
+    {
+      if(this->size() != arrayRows * arrayColumns) {
+        this->reinit(arrayRows, arrayColumns);
+      } else {
+        if(this->rows() != arrayRows) {
+          this->reshape(arrayRows, arrayColumns);
+        }
+      }
+    }
+
+
     /* After reshaping, matrix is still row major order */
     template <class Type>
     void Array2D<Type>::
