@@ -7,8 +7,8 @@
 * Copyright (C) 2001-2007 David LaRose, dlr@cs.cmu.edu
 * See accompanying file, LICENSE.TXT, for details.
 *
-* $Revision: 1038 $
-* $Date: 2008-09-29 14:15:18 -0400 (Mon, 29 Sep 2008) $
+* $Revision: 1182 $
+* $Date: 2009-09-09 11:25:46 -0400 (Wed, 09 Sep 2009) $
 ***************************************************************************
 **/
 
@@ -378,7 +378,8 @@ namespace dlr {
       /** 
        * Changes the shape of the array and reallocates storage.  The
        * current array contents are lost.  After a successful call to
-       * reinit(), the array will have arrayShape0 x arrayShape1 x arrayShape2 elements.
+       * reinit(), the array will have arrayShape0 x arrayShape1 x arrayShape2
+       * elements.
        * 
        * @param arrayShape0 Requested dimension along axis 0.
        * @param arrayShape1 Requested dimension along axis 1.
@@ -387,6 +388,23 @@ namespace dlr {
       void
       reinit(size_t arrayShape0, size_t arrayShape1, size_t arrayShape2);
 
+
+      /** 
+       * Behaves just like member function reinit() unless *this
+       * already has the requested shape, in which case this member
+       * function does nothing, or *this has the requested size (but a
+       * different shape), in which case this member function behaves
+       * just like member function resize().
+       * 
+       * @param arrayShape0 Requested dimension along axis 0.
+       * @param arrayShape1 Requested dimension along axis 1.
+       * @param arrayShape2 Requested dimension along axis 2.
+       */
+      inline void
+      reinitIfNecessary(size_t arrayShape0, size_t arrayShape1,
+                        size_t arrayShape2);
+
+      
       /**
        * Changes the shape of the array.  It is an error if arrayShape0 *
        * arrayShape1 * arrayShape2 is not equal to this->size().  Any one argument
@@ -553,7 +571,7 @@ namespace dlr {
        * @param index Indicates the selected element.
        * @return Reference to the (index)th element of the array.
        */
-      Type&
+      inline Type&
       operator()(size_t index) {
         checkBounds(index);
         return m_dataPtr[index];
@@ -566,7 +584,7 @@ namespace dlr {
        * @param index Indicates the selected element.
        * @return Value of the (index)th element of the array.
        */
-      Type
+      inline Type
       operator()(size_t index) const {
         checkBounds(index);
         return m_dataPtr[index];
@@ -585,7 +603,7 @@ namespace dlr {
        * along the third axis.
        * @return Reference to the selected element of the array.
        */
-      Type&
+      inline Type&
       operator()(size_t index0, size_t index1, size_t index2) {
         checkBounds(index0, index1, index2);
         return m_dataPtr[index2 + (index1 * m_shape2)
@@ -605,7 +623,7 @@ namespace dlr {
        * along the third axis.
        * @return Value of the selected element of the array.
        */
-      Type
+      inline Type
       operator()(size_t index0, size_t index1, size_t index2) const {
         checkBounds(index0, index1, index2);
         return m_dataPtr[index2 + (index1 * m_shape2)
@@ -619,7 +637,7 @@ namespace dlr {
        * @param index Indicates the selected element.
        * @return Reference to the (index)th element of the array.
        */
-      Type&
+      inline Type&
       operator[](size_t index) {return this->operator()(index);}
 
       /** 
@@ -629,7 +647,7 @@ namespace dlr {
        * @param index Indicates the selected element.
        * @return Value of the (index)th element of the array.
        */
-      Type
+      inline Type
       operator[](size_t index) const {return this->operator()(index);}
 
       /** 
@@ -1458,6 +1476,22 @@ namespace dlr {
     }
 
 
+    template <class Type>
+    void Array3D<Type>::
+    reinitIfNecessary(size_t arrayShape0, size_t arrayShape1,
+                      size_t arrayShape2)
+    {
+      if(this->size() != arrayShape0 * arrayShape1 * arrayShape2) {
+        this->reinit(arrayShape0, arrayShape1, arrayShape2);
+      } else {
+        if(this->shape0() != arrayShape0
+           || this->shape1() != arrayShape1) {
+          this->reshape(arrayShape0, arrayShape1, arrayShape2);
+        }
+      }
+    }
+
+
     template <class Type>
     void Array3D<Type>::
     reshape(int arrayShape0, int arrayShape1, int arrayShape2)
