@@ -152,7 +152,7 @@ namespace dlr {
        * pre-integration was performed.
        * 
        * @param corner1 This argument specifies the region corner
-       * diagonally opposit to corner0.  If the array was set using
+       * diagonally opposite to corner0.  If the array was set using
        * the single-argument constructor or single-argument version of
        * setArray, then corner1 specifies the corner as an index into
        * the entire array.  If the array was set using the
@@ -200,6 +200,41 @@ namespace dlr {
       getIntegral(const Index2D& corner0, const Index2D& corner1, bool dummy);
 
 
+      /** 
+       * This member function returns the raw 2D integral from which
+       * box integration is performed.  It is normally used only by
+       * other functions in the dlr_libs suite of libraries, but is a
+       * stable part of the BoxIntegrator interface.
+       *
+       * @param row This argument specifies the row (relative to the
+       * region over which pre-integration was performed) at which to
+       * sample the raw integral.
+       * 
+       * @param column This argument specifies the column (relative to
+       * the region over which pre-integration was performed) at which
+       * to sample the raw integral.
+       * 
+       * @return The return value is the value of the raw pre-integral
+       * at the specified location.
+       */
+      Type1
+      getRawIntegral(size_t row, size_t column);
+
+
+      /** 
+       * This member function is just like getRawIntegral(size_t,
+       * size_t), but uses raster-order single indexing.
+       *
+       * @param index0 This argument specifies the location at which
+       * to sample the raw integral.
+       * 
+       * @return The return value is the value of the raw pre-integral
+       * at the specified location.
+       */
+      Type1
+      getRawIntegral(size_t index0);
+
+
       /** 
        * This member function discards and previously cached integral
        * information, performs a double integral over the input array,
@@ -363,6 +398,20 @@ namespace dlr {
     }
 
 
+    // This constructor initializes the class instance, and then
+    // passes its arguments to member function setArray() in order
+    // to precompute integral information.
+    template <class Type0, class Type1>
+    template <class Functor>
+    BoxIntegrator2D<Type0, Type1>::
+    BoxIntegrator2D(const Array2D<Type0>& inputArray, Functor functor)
+      : m_cache(),
+        m_corner0(0, 0)
+    {
+      this->setArray(inputArray, functor);
+    }
+
+
     // This constructor works just like the single argument version
     // of setArray, with the exception that the pre-integration is
     // performed over only a rectangular sub-array.
@@ -427,6 +476,28 @@ namespace dlr {
     }
 
 
+    // This member function returns the raw 2D integral from which box
+    // integration is performed.
+    template <class Type0, class Type1>
+    Type1
+    BoxIntegrator2D<Type0, Type1>::
+    getRawIntegral(size_t row, size_t column)
+    {
+      return m_cache(row, column);
+    }
+
+
+    // This member function works just like member function
+    // getRawIntegral(size_t, size_t), but uses raster-indexing.
+    template <class Type0, class Type1>
+    Type1
+    BoxIntegrator2D<Type0, Type1>::
+    getRawIntegral(size_t index0)
+    {
+      return m_cache(index0);
+    }
+
+
     // This member function discards and previously cached integral
     // information, performs a double integral over the input array,
     // and caches the result for future use in computing
