@@ -264,7 +264,8 @@ namespace dlr {
         return 1.0E-6;
       }
       Float32 exponent = static_cast<Float32>(std::log(scale) / std::log(2.0));
-      return static_cast<Float32>(10.0 * std::pow(2.0, exponent - 23));
+      return static_cast<Float32>(
+        10.0 * std::pow((double)2.0, (double)(exponent - 23)));
     }
 
     // Adaptive tolerance is necessary to avoid trouble with float
@@ -278,7 +279,8 @@ namespace dlr {
         return 1.0E-12;
       }
       Float64 exponent = static_cast<Float32>(std::log(scale) / std::log(2.0));
-      return static_cast<Float32>(10.0 * std::pow(2.0, exponent - 52));
+      return static_cast<Float32>(
+        10.0 * std::pow((double)2.0, (double)(exponent - 52)));
     }
 
     
@@ -522,8 +524,9 @@ namespace dlr {
       // different precisions, leading to unexpected answers!  We
       // solve this by having an adaptive tolerance for 32bit floats.
       for(size_t index0 = 0; index0 < array0.size(); ++index0) {
-        typename Functor1::result_type targetValue = elementFunctor(
-          array0Copy[index0], array1[index0]);
+        // typename Functor1::result_type targetValue = elementFunctor(
+        //   array0Copy[index0], array1[index0]);
+        elementFunctor(array0Copy[index0], array1[index0]);
         typename ArrayType::value_type tolerance =
           getTolerance<typename ArrayType::value_type>(array0Copy[index0]);
         DLR_TEST_ASSERT(approximatelyEqual(array0[index0], array0Copy[index0],
