@@ -7,8 +7,8 @@
 * Copyright (C) 2005 David LaRose, dlr@cs.cmu.edu
 * See accompanying file, LICENSE.TXT, for details.
 *
-* $Revision: 996 $
-* $Date: 2008-01-12 01:10:03 -0500 (Sat, 12 Jan 2008) $
+* $Revision: 1211 $
+* $Date: 2009-10-08 19:04:39 -0400 (Thu, 08 Oct 2009) $
 ***************************************************************************
 **/
 
@@ -31,8 +31,8 @@ namespace dlr {
     UtilitiesTemplateTest(const std::string& typeName);
     ~UtilitiesTemplateTest() {}
 
-    void setUp(const std::string& testName) {}
-    void tearDown(const std::string& testName) {}
+    void setUp(const std::string&) {}
+    void tearDown(const std::string&) {}
 
     void testAbs0();
     void testAbs1();
@@ -61,6 +61,9 @@ namespace dlr {
     void testCount();
     void testNormalizedCorrelation();
     void testSum0();
+    void testTake_Array1D_Array1D();
+    void testTake_Array2D_Array1D();
+    void testTake_Array2D_Array1D_unsignedInt();
 
   private:
 
@@ -115,6 +118,9 @@ namespace dlr {
     DLR_TEST_REGISTER_MEMBER(testCount);
     DLR_TEST_REGISTER_MEMBER(testNormalizedCorrelation);
     DLR_TEST_REGISTER_MEMBER(testSum0);
+    DLR_TEST_REGISTER_MEMBER(testTake_Array1D_Array1D);
+    DLR_TEST_REGISTER_MEMBER(testTake_Array2D_Array1D);
+    DLR_TEST_REGISTER_MEMBER(testTake_Array2D_Array1D_unsignedInt);
   }
 
 
@@ -613,6 +619,61 @@ namespace dlr {
   }
     
 
+  template <class Type>
+  void
+  UtilitiesTemplateTest<Type>::
+  testTake_Array1D_Array1D()
+  {
+    Array1D<Type> dataArray("[0, 1, 2, 3, 4, 5]");
+    Array1D<unsigned int> indexArray("[2, 1, 1, 4]");
+    Array1D<Type> resultArray = take(dataArray, indexArray);
+
+    Array1D<Type> referenceArray("[2, 1, 1, 4]");
+    DLR_TEST_ASSERT(this->equivalent(resultArray, referenceArray,
+                                     static_cast<Type>(0)));
+  }
+
+
+  template <class Type>
+  void
+  UtilitiesTemplateTest<Type>::
+  testTake_Array2D_Array1D()
+  {
+    Array2D<Type> dataArray("[[0, 1, 2], [3, 4, 5]]");
+    Array1D<unsigned int> indexArray("[2, 1, 1, 4]");
+    Array1D<Type> resultArray = take(dataArray, indexArray);
+
+    Array1D<Type> referenceArray("[2, 1, 1, 4]");
+    DLR_TEST_ASSERT(this->equivalent(resultArray, referenceArray,
+                                     static_cast<Type>(0)));
+  }
+
+
+  template <class Type>
+  void
+  UtilitiesTemplateTest<Type>::
+  testTake_Array2D_Array1D_unsignedInt()
+  {
+    Array2D<Type> dataArray("[[0, 1, 2], "
+                            " [3, 4, 5], "
+                            " [6, 7, 8], "
+                            " [9, 10, 11]]");
+    Array1D<unsigned int> indexArray("[0, 2]");
+    Array2D<Type> resultArray0 = take(dataArray, indexArray, 0);
+    Array2D<Type> resultArray1 = take(dataArray, indexArray, 1);
+
+    Array2D<Type> referenceArray0("[[0, 1, 2],"
+                                  " [6, 7, 8]]");
+    Array2D<Type> referenceArray1("[[0, 2],"
+                                  " [3, 5],"
+                                  " [6, 8],"
+                                  " [9, 11]]");
+    DLR_TEST_ASSERT(this->equivalent(resultArray0, referenceArray0,
+                                     static_cast<Type>(0)));
+    DLR_TEST_ASSERT(this->equivalent(resultArray1, referenceArray1,
+                                     static_cast<Type>(0)));
+  }
+
   template <class Type>
   template <class Type2>
   bool
